/* Tree Clone.
   
This file is part of GCC.
   
GCC is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.
   
GCC is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.
   
You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING.  If not, write to the Free
Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301, USA.  */

#include "clone.h"

GTY(()) tree detect_cpu_flags;

bool is_clonable (struct cgraph_node *cg_func)
{
  if (cg_func->global.inlined_to)
    return false;

  if (cgraph_function_body_availability (cg_func) == AVAIL_NOT_AVAILABLE)
    return false;

  return true;
}

void rename_function(tree decl, const char *prefix, const char *suffix) {
	const char *name=IDENTIFIER_POINTER(DECL_NAME(decl));
	char *newname;
	int len=strlen(name)+1;
	if(prefix) len+=strlen(prefix);
	if(suffix) len+=strlen(suffix);
	newname=xmalloc(len);
	if(prefix) {
		strcpy(newname,prefix);
		strcat(newname,name);
	}
	else
	strcpy(newname,name);
	if(suffix)
	strcat(newname,suffix);	
	DECL_NAME(decl)=get_identifier(newname);
	free(newname);
}

/* Naive */
bool is_renamed_function(tree decl, const char *prefix, const char *suffix) {
	const char *name=IDENTIFIER_POINTER(DECL_NAME(decl));
	int len=strlen(name);
	int leno,i;
	if(prefix) {
		leno=strlen(prefix);
		for(i=0;i<leno;++i) {
			if(name[i]!=prefix[i]) {
				return false;
			}
		}
	}
	if(suffix) {
		leno=len-strlen(suffix);
		for(i=leno;i<len;++i) {	
			if(name[i]!=suffix[i]) {
				return false;
			}
		}
	}
	return true;
}
